@@ -10,20 +10,21 @@
    This file is part of the GNU Objective C User Interface Library.
 
    This library is free software; you can redistribute it and/or
-   modify it under the terms of the GNU Library General Public
+   modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.
-   
+
    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
-   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-   Library General Public License for more details.
-   
-   You should have received a copy of the GNU Library General Public
-   License along with this library; if not, write to the Free
-   Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-   Boston, MA 02111 USA.
-   */
+   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
+   Lesser General Public License for more details.
+
+   You should have received a copy of the GNU Lesser General Public
+   License along with this library; see the file COPYING.LIB.
+   If not, see <http://www.gnu.org/licenses/> or write to the 
+   Free Software Foundation, 51 Franklin Street, Fifth Floor, 
+   Boston, MA 02110-1301, USA.
+*/
 
 #ifndef _GSGState_h_INCLUDE
 #define _GSGState_h_INCLUDE
@@ -36,6 +37,7 @@
 @class NSAffineTransform;
 @class NSBezierPath;
 @class NSFont;
+@class NSColorSpace;
 @class GSContext;
 
 typedef enum {
@@ -56,8 +58,8 @@ typedef enum {
   NSPoint offset;               /* Offset from Drawable origin */
   NSBezierPath *path;	        /* Current path */
   GSFontInfo *font;             /* Current font reference */
-  NSColor *fillColorS;          /* Color(space) used for fill drawing */
-  NSColor *strokeColorS;        /* Color(space) used for stroke drawing */
+  NSColorSpace *fillColorS;     /* Colorspace used for fill drawing */
+  NSColorSpace *strokeColorS;   /* Colorspace used for stroke drawing */
   device_color_t fillColor;     /* fill color */
   device_color_t strokeColor;   /* stroke color */
   color_state_t  cstate;        /* state last time color was set */
