@@ -34,10 +34,10 @@
 - (LRESULT) decodeWM_ACTIVEParams:(WPARAM)wParam : (LPARAM)lParam : (HWND)hwnd
 {
   // decode our params
-  flags._last_WM_ACTIVATE = LOWORD(wParam);
+  int last_WM_ACTIVATE = LOWORD(wParam);
   //int minimized = HIWORD(wParam);
 
-  switch (flags._last_WM_ACTIVATE)
+  switch (last_WM_ACTIVATE)
     {
       case WA_ACTIVE:  //deactivate
         {
@@ -66,48 +66,16 @@
 - (LRESULT) decodeWM_ACTIVEAPPParams: (HWND)hwnd : (WPARAM)wParam 
                                     : (LPARAM)lParam
 {
-  BOOL active = [NSApp isActive];
-          
   switch ((int)wParam)
     {
       case TRUE:
         {
-          if (active==YES)
-            {
-              if (flags._is_menu==YES) // have menu and app active
-                {
-                  // future implimentation if needed
-                }
-              else  // Not a menu and app is active
-                {
-                  // window is Visable
-                  if ([EVENT_WINDOW(hwnd) isVisible]==YES) 
-                    {
-                      // future implimentation if needed
-                    }    
-                  else
-                    {
-                      // future implimentation if needed
-                    }
-                }
-            }
-          else  // app is not active
-            {
-              [NSApp activateIgnoringOtherApps:YES];
-              flags._eventHandled=YES;
-            }    
+          [NSApp activateIgnoringOtherApps: YES];
+          flags._eventHandled = YES;
         }
         break;
       case FALSE:
         {
-          if (flags._is_menu==YES)
-            {
-              // future implimentation if needed
-            }
-          else
-            {
-              // future implimentation if needed
-            }             
         }            
         break;
               
