@@ -216,8 +216,17 @@ static NSString		*xWaitMode = @"XPasteboardWaitMode";
   /*
    * Set up atoms for use in X selection mechanism.
    */
-  XInternAtoms(xDisplay, atom_names, sizeof(atom_names)/sizeof(char*),
-    False, atoms);
+#ifdef HAVE_XINTERNATOMS
+   XInternAtoms(xDisplay, atom_names, sizeof(atom_names)/sizeof(char*),
+                False, atoms);
+#else
+   {
+     int atomCount;
+
+     for (atomCount = 0; atomCount < sizeof(atom_names)/sizeof(char*); atomCount++)
+       atoms[atomCount] = XInternAtom(xDisplay, atom_names[atomCount], False);
+   }
+#endif
 
   xRootWin = RootWindow(xDisplay, DefaultScreen(xDisplay));
   xAppWin = XCreateSimpleWindow(xDisplay, xRootWin,
@@ -314,7 +323,14 @@ static NSString		*xWaitMode = @"XPasteboardWaitMode";
 
   while ((count = XPending(xDisplay)) > 0)
     {
+#if 0
+      /* Don't attempt to be smart here. We may enter this method recursively
+       * when further data is requested while processing this event, which
+       * means that the count will not longer be correct when returning to
+       * the outer invocation.
+       */
       while (count-- > 0)
+#endif
         {
           XEvent	xEvent;
 
